@@ -157,7 +157,7 @@ def init_mc(memcached_addr=None,disable_local_cached=False):
         import lrucache
         class FakeMemcacheClient(object):
             def __init__(self):
-                self.cache = LRUCache(4096)
+                self.cache = lrucache.LRUCache(4096)
 
             def __getattr__(self,*args,**kwargs):
                 def func(*args,**kwargs):
